@@ -11,7 +11,7 @@
 #'                    Defaults to FALSE; if TRUE, only needs to be called once per
 #'                    dataset.  If variables dataset is already cached via the
 #'                    \code{load_variables} function, this can be bypassed.
-#' @param year The year for which you are requesting data.  1990, 2000, and 2010 are available.
+#' @param year The year for which you are requesting data.   are available.
 #' @param sumfile The Census summary file.  Defaults to sf1; the function will look in sf3 if it
 #'                cannot find a variable in sf1.
 #' @param state The state for which you are requesting data. State
@@ -23,7 +23,7 @@
 #' @param geometry if FALSE (the default), return a regular tibble of ACS data.
 #'                 if TRUE, uses the tigris package to return an sf tibble
 #'                 with simple feature geometry in the `geometry` column.  state, county, tract, and block group are
-#'                 supported for 1990 through 2010; block and ZCTA geometry are supported for 2000 and 2010.
+#'                 supported for 2000 through 2020; block and ZCTA geometry are supported for 2000 and 2010.
 #' @param output One of "tidy" (the default) in which each row represents an
 #'               enumeration unit-variable combination, or "wide" in which each
 #'               row represents an enumeration unit and the variables are in the
@@ -79,6 +79,18 @@ get_decennial <- function(geography, variables = NULL, table = NULL, cache_table
 
   message(sprintf("Getting data from the %s decennial Census", year))
 
+  if (year == 2020) {
+    sumfile <- "pl"
+  }
+
+  if (year == 2020 && sumfile == "pl" && geography == "public use microdata area") {
+    stop("PUMAs are not defined yet for the 2020 decennial Census.", call. = FALSE)
+  }
+
+  if (geography == "voting district" && year != 2020) {
+    stop("`year` must be 2020 for voting districts.", call. = FALSE)
+  }
+
   if (Sys.getenv('CENSUS_API_KEY') != '') {
 
     key <- Sys.getenv('CENSUS_API_KEY')
@@ -127,6 +139,10 @@ get_decennial <- function(geography, variables = NULL, table = NULL, cache_table
     geography <- "zip code tabulation area (or part)"
   }
 
+  if (year == 2020 && sumfile == "pl" && geography == "zip code tabulation area") {
+    stop("ZCTAs are not currently available for the 2020 decennial Census.", call. = FALSE)
+  }
+
   # if (geography == "zip code tabulation area" && is.null(state)) {
   #   stop("ZCTA data for the decennial Census is only available by state from tidycensus.",
   #        call. = FALSE)
@@ -185,7 +201,7 @@ get_decennial <- function(geography, variables = NULL, table = NULL, cache_table
   if ((geography == "tract" || geography == "block group" || geography == "block") && length(state) > 1) {
     # mc <- match.call(expand.dots = TRUE)
     if (geometry) {
-      result <- map(state, ~{
+      result <- map(state, function(s, ...) {
         suppressMessages(
           insist_get_decennial(geography = geography,
                                variables = variables,
@@ -194,16 +210,17 @@ get_decennial <- function(geography, variables = NULL, table = NULL, cache_table
                                year = year,
                                sumfile = sumfile,
                                output = output,
-                               state = .x,
+                               state = s,
                                county = county,
                                geometry = geometry,
                                keep_geo_vars = keep_geo_vars,
                                shift_geo = FALSE,
                                summary_var = summary_var,
                                key = key,
-                               show_call = show_call)
-          )
-      }) %>%
+                               show_call = show_call,
+                               ...)
+        )
+      }, ...) %>%
         reduce(rbind)
       geoms <- unique(st_geometry_type(result))
       if (length(geoms) > 1) {
@@ -247,7 +264,7 @@ get_decennial <- function(geography, variables = NULL, table = NULL, cache_table
 
     dat <- map(l, function(x) {
       d <- try(load_data_decennial(geography, x, key, year, sumfile, state, county, show_call = show_call),
-                 silent = silent)
+               silent = silent)
       # If sf1 fails, try to get it from sf3
       if (inherits(d, "try-error") && year < 2010) {
 
@@ -258,8 +275,10 @@ get_decennial <- function(geography, variables = NULL, table = NULL, cache_table
       } else {
         if (sumfile == "sf3") {
           message("Using Census Summary File 3")
-        } else {
+        } else if (sumfile == "sf1") {
           message("Using Census Summary File 1")
+        } else if (sumfile == "pl") {
+          message("Using the PL 94-171 Redistricting Data summary file")
         }
       }
       d
@@ -280,8 +299,10 @@ get_decennial <- function(geography, variables = NULL, table = NULL, cache_table
     } else {
       if (sumfile == "sf3") {
         message("Using Census Summary File 3")
-      } else {
+      } else if (sumfile == "sf1") {
         message("Using Census Summary File 1")
+      } else if (sumfile == "pl") {
+        message("Using the PL 94-171 Redistricting Data summary file")
       }
     }
 
@@ -320,11 +341,11 @@ get_decennial <- function(geography, variables = NULL, table = NULL, cache_table
   if (!is.null(summary_var)) {
 
     sumdat <- suppressMessages(try(load_data_decennial(geography, summary_var, key, year,
-                                                   sumfile, state, county, show_call = show_call)))
+                                                       sumfile, state, county, show_call = show_call)))
 
     if (inherits(sumdat, "try-error")) {
       sumdat <- suppressMessages(try(load_data_decennial(geography, summary_var, key, year,
-                                        sumfile = "sf3", state, county, show_call = show_call)))
+                                                         sumfile = "sf3", state, county, show_call = show_call)))
     }
 
     dat2 <- dat2 %>%
@@ -339,7 +360,6 @@ get_decennial <- function(geography, variables = NULL, table = NULL, cache_table
 
     if (shift_geo) {
 
-
       if (!is.null(state)) {
         stop("`shift_geo` is only available when requesting geometry for the entire US", call. = FALSE)
       }
@@ -361,7 +381,7 @@ get_decennial <- function(geography, variables = NULL, table = NULL, cache_table
     } else {
 
       geom <- try(suppressMessages(use_tigris(geography = geography, year = year,
-                                          state = state, county = county, ...)))
+                                              state = state, county = county, ...)))
 
       if ("try-error" %in% class(geom)) {
         stop("Your geometry data download failed. Please try again later or check the status of the Census Bureau website at https://www2.census.gov/geo/tiger/", call. = FALSE)
@@ -384,10 +404,36 @@ get_decennial <- function(geography, variables = NULL, table = NULL, cache_table
         st_as_sf()
     }
 
+    # Give users a heads-up about differential privacy in the 2020 decennial data
+    # This should print as the final message before data are returned
+    if (year == 2020) {
+
+      msg <- c(crayon::cyan(stringr::str_wrap("Note: 2020 decennial Census data use differential privacy, a technique that introduces errors into data to preserve respondent confidentiality.")),
+               i = crayon::magenta("Small counts should be interpreted with caution."),
+               i = crayon::magenta("See https://www.census.gov/library/fact-sheets/2021/protecting-the-confidentiality-of-the-2020-census-redistricting-data.html for additional guidance."))
+
+      rlang::inform(msg, .frequency = "once",
+                    .frequency_id = "msg2020")
+
+    }
+
     return(out)
 
   } else {
 
+    # Give users a heads-up about differential privacy in the 2020 decennial data
+    # This should print as the final message before data are returned
+    if (year == 2020) {
+
+      msg <- c(crayon::cyan(stringr::str_wrap("Note: 2020 decennial Census data use differential privacy, a technique that introduces errors into data to preserve respondent confidentiality.")),
+               i = crayon::magenta("Small counts should be interpreted with caution."),
+               i = crayon::magenta("See https://www.census.gov/library/fact-sheets/2021/protecting-the-confidentiality-of-the-2020-census-redistricting-data.html for additional guidance."))
+
+      rlang::inform(msg, .frequency = "once",
+                    .frequency_id = "msg2020")
+
+    }
+
     return(dat2)
 
   }
