@@ -3,8 +3,8 @@
 #' @param geography The geography of your data.
 #' @param product The data product (optional). \code{"population"}, \code{"components"}
 #'                \code{"housing"}, and \code{"characteristics"} are supported.
-#' @param variables A character string of requested variables to get specific
-#'                  variables from the population, components, and housing APIs.
+#' @param variables A character string or vector of character strings of requested variables
+#'                  to get from either the population, components, or housing API.
 #' @param breakdown The population breakdown used when \code{product = "characteristics"}.
 #'                  Acceptable values are \code{"AGEGROUP"}, \code{"RACE"}, \code{"SEX"}, and
 #'                  \code{"HISP"}, for Hispanic/Not Hispanic.  These values can be combined in
@@ -12,7 +12,7 @@
 #'                  combinations of these breakdowns.
 #' @param breakdown_labels Whether or not to label breakdown elements returned when
 #'                         \code{product = "characteristics"}. Defaults to FALSE.
-#' @param year The data year (defaults to 2018)
+#' @param year The data year (defaults to 2019)
 #' @param state The state for which you are requesting data. State
 #'              names, postal codes, and FIPS codes are accepted.
 #'              Defaults to NULL.
@@ -23,7 +23,7 @@
 #'                    of 2010. The returned column is either "DATE", representing a particular estimate date, or "PERIOD",
 #'                    representing a time period (e.g. births between 2016 and 2017), and contains integers representing
 #'                    those values.  Integer to date or period mapping is available at
-#'                    \url{https://www.census.gov/data/developers/data-sets/popest-popproj/popest/popest-vars/2018.html}.
+#'                    \url{https://www.census.gov/data/developers/data-sets/popest-popproj/popest/popest-vars/2019.html}.
 #' @param output One of "tidy" (the default) in which each row represents an
 #'               enumeration unit-variable combination, or "wide" in which each
 #'               row represents an enumeration unit and the variables are in the
@@ -33,10 +33,11 @@
 #'                 with simple feature geometry in the `geometry` column.
 #' @param keep_geo_vars if TRUE, keeps all the variables from the Census
 #'                      shapefile obtained by tigris.  Defaults to FALSE.
-#' @param shift_geo if TRUE, returns geometry with Alaska and Hawaii shifted for thematic
-#'                  mapping of the entire US.
+#' @param shift_geo (deprecated) if TRUE, returns geometry with Alaska and Hawaii shifted for thematic
+#'                  mapping of the entire US.  As of May 2021, we recommend using \code{tigris::shift_geometry()}
+#'                  instead.
 #' @param key Your Census API key.
-#'            Obtain one at \url{http://api.census.gov/data/key_signup.html}.  Can be stored
+#'            Obtain one at \url{https://api.census.gov/data/key_signup.html}.  Can be stored
 #'            in your .Renviron with \code{census_api_key("YOUR KEY", install = TRUE)}
 #' @param show_call if TRUE, display call made to Census API. This can be very useful
 #'                  in debugging and determining if error messages returned are
@@ -53,6 +54,10 @@ get_estimates <- function(geography, product = NULL, variables = NULL,
                           output = "tidy", geometry = FALSE, keep_geo_vars = FALSE,
                           shift_geo = FALSE, key = NULL, show_call = FALSE, ...) {
 
+  if (shift_geo) {
+    warning("The `shift_geo` argument is deprecated and will be removed in a future release. We recommend using `tigris::shift_geometry()` instead.", call. = FALSE)
+  }
+
   if (year < 2015) {
     stop("The Population Estimates API is not available in tidycensus for years prior to 2015. Consider using `time_series = TRUE` or the censusapi package for earlier estimates.")
   }
@@ -368,8 +373,12 @@ get_estimates <- function(geography, product = NULL, variables = NULL,
 
     } else {
 
-      geom <- suppressMessages(use_tigris(geography = geography, year = year,
-                                          state = state, county = county, ...))
+      geom <- try(suppressMessages(use_tigris(geography = geography, year = year,
+                                          state = state, county = county, ...)))
+
+      if ("try-error" %in% class(geom)) {
+        stop("Your geometry data download failed. Please try again later or check the status of the Census Bureau website at https://www2.census.gov/geo/tiger/", call. = FALSE)
+      }
     }
 
     if (! keep_geo_vars) {
@@ -398,4 +407,4 @@ get_estimates <- function(geography, product = NULL, variables = NULL,
 
 
 
-}
\ No newline at end of file
+}
