@@ -172,10 +172,12 @@ use_tigris <- function(geography, year, cb = TRUE, resolution = "500k",
 
     bl <- blocks(state = state, county = county, year = year, class = "sf", ...)
 
-    if (year > 2000) {
+    if (year == 2010) {
       bl <- rename(bl, GEOID = GEOID10)
     } else if (year == 2000) {
       bl <- rename(bl, GEOID = BLKIDFP00)
+    } else if (year == 2020) {
+      bl <- rename(bl, GEOID = GEOID20)
     }
 
     return(bl)
@@ -200,6 +202,9 @@ use_tigris <- function(geography, year, cb = TRUE, resolution = "500k",
 
   } else if (geography == "public use microdata area") {
 
+    # Right now, PUMAs are not defined for 2020 and are not in the CB file
+    if (year == 2020) cb <- FALSE
+
     state_ids <- c("AL", "AK", "AZ", "AR", "CA", "CO", "CT", "DE", "FL", "GA",
                    "HI", "ID", "IL", "IN", "IA", "KS", "KY", "LA", "ME", "MD", "MA",
                    "MI", "MN", "MS", "MO", "MT", "NE", "NV", "NH", "NJ", "NM", "NY",
@@ -238,9 +243,7 @@ use_tigris <- function(geography, year, cb = TRUE, resolution = "500k",
 
     return(slc)
 
-  } else if (geography %in% c("american indian area/alaska native area/hawaiian home land",
-                              "american indian area/alaska native area (reservation or statistical entity only)",
-                              "american indian area (off-reservation trust land only)/hawaiian home land")) {
+  } else if (geography == c("american indian area/alaska native area/hawaiian home land")) {
 
     nv <- native_areas(cb = cb, year = year, class = "sf", ...)
 
@@ -269,6 +272,9 @@ use_tigris <- function(geography, year, cb = TRUE, resolution = "500k",
 
   } else if (geography == "urban area") {
 
+    # Right now, urban areas are not defined for 2020 and are not in the CB file
+    if (year == 2020) cb <- FALSE
+
     ua <- urban_areas(cb = cb, year = year, class = "sf", ...)
 
     ua <- rename(ua, GEOID = GEOID10)
@@ -347,6 +353,25 @@ use_tigris <- function(geography, year, cb = TRUE, resolution = "500k",
 
     return(div)
 
+  } else if (geography == "alaska native regional corporation") {
+
+    anrc <- alaska_native_regional_corporations(year = year, ...)
+
+    return(anrc)
+
+  } else if (geography == "voting district") {
+
+    if (!is.null(county) && length(county) == 1) {
+      vtds <- voting_districts(state = state, county = county,
+                               year = 2020, cb = cb, ...)
+    } else {
+      vtds <- voting_districts(state = state, year = 2020, cb = cb, ...)
+    }
+
+    vtds <- dplyr::rename(vtds, GEOID = GEOID20)
+
+    return(vtds)
+
   } else {
 
     # Leave this in as a legacy piece in case something changes
