@@ -65,12 +65,6 @@ get_pums <- function(variables = NULL,
                     startyear, year))
   }
 
-  # Allow users to get all states by specifying "all"
-  if (all(state == "all")) {
-    message("Requesting data for the entire United States. This can take several minutes to complete.")
-    state <- NULL
-  }
-
   if (Sys.getenv('CENSUS_API_KEY') != '') {
 
     key <- Sys.getenv('CENSUS_API_KEY')
@@ -81,6 +75,33 @@ get_pums <- function(variables = NULL,
 
   }
 
+
+  # Allow users to get all states by specifying "all"
+  # To avoid large data timeout errors, iterate through the states instead.
+  if (all(state == "all")) {
+
+    state_codes <- unique(fips_codes$state_code)[1:51]
+
+    message("Requesting data for the entire United States by state then combining the result.\nThis can take several minutes to complete.\nFor large data extract workflows, consider downloading data from the Census FTP server\nor from IPUMS (https://ipums.org) instead.")
+    output <- purrr::map_dfr(state_codes, function(each_state) {
+      suppressMessages(get_pums(
+        state = each_state,
+        variables = variables,
+        puma = NULL,
+        year = year,
+        survey = survey,
+        variables_filter = variables_filter,
+        rep_weights = rep_weights,
+        recode = recode,
+        show_call = TRUE,
+        key = key
+      ))
+    })
+
+    return(output)
+
+  }
+
   # If variables is NULL, initialize a length-0 vector to store
   # the required variables eventually
   if (is.null(variables)) {
